==> elgg-1.9.2.zip: elgg-1.9.2/mod/reportedcontent/languages/de.php <==
<?php
return array(

	'item:object:reported_content' => 'Gemeldete Beiträge',
	'admin:administer_utilities:reportedcontent' => 'Gemeldete Beiträge',
	'reportedcontent' => 'Gemeldete Beiträge',
	'reportedcontent:this' => 'Beitrag melden',
	'reportedcontent:this:tooltip' => 'Melde diese Seiten/diesen Beitrag einem Administrator.',
	'reportedcontent:none' => 'Es gibt keine gemeldeten Beiträge.',
	'reportedcontent:report' => 'Einem Admin melden',
	'reportedcontent:deleted' => 'Die Meldung wurde gelöscht.',
	'reportedcontent:notdeleted' => 'Die Meldung konnte nicht gelöscht werden.',
	'reportedcontent:delete' => 'Meldung löschen',
	'reportedcontent:areyousure' => 'Bist Du sicher, dass Du das löschen willst?',
	'reportedcontent:archive' => 'Meldung archivieren',
	'reportedcontent:archived' => 'Die Meldung wurde archiviert.',
	'reportedcontent:visit' => 'Gemeldeten Beitrag anzeigen',
	'reportedcontent:by' => 'Gemeldet von',
	'reportedcontent:objecttitle' => 'Titel des gemeldeten Beitrags',
	'reportedcontent:objecturl' => 'URL des gemeldeten Beitrags',
	'reportedcontent:reason' => 'Grund für die Meldung',
	'reportedcontent:description' => 'Warum möchtest Du diesen Beitrag melden?',
	'reportedcontent:address' => 'Adresse des Beitrags',
	'reportedcontent:success' => 'Deine Meldung wurde an den Admin gesendet.',
	'reportedcontent:failing' => 'Deine Meldung konnte nicht gesendet werden.',
	'reportedcontent:report' => 'Einem Admin melden',
	'reportedcontent:instructions' => 'Die Meldung wird an die Administratoren dieser Community-Seite gesendet, damit sie auf diesen Beitrag aufmerksam gemacht werden.',
	'reportedcontent:numbertodisplay' => 'Anzahl der anzuzeigenden Meldungen',
	'reportedcontent:widget:description' => 'Gemeldete Beiträge anzeigen.',
	'reportedcontent:user' => 'Benutzer melden',

	'reportedcontent:failed' => 'Entschuldigung, leider ist der Versuch, diesen Beitrag zu melden, gescheitert.',
	'reportedcontent:notarchived' => 'Die Meldung konnte nicht archiviert werden.',
);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/reportedcontent/languages/de.php <==
<?php
return array(

	'item:object:reported_content' => 'Gemeldete Beiträge',
	'admin:administer_utilities:reportedcontent' => 'Gemeldete Beiträge',
	'reportedcontent' => 'Gemeldete Beiträge',
	'reportedcontent:this' => 'Beitrag melden',
	'reportedcontent:this:tooltip' => 'Melde diese Seiten/diesen Beitrag einem Administrator.',
	'reportedcontent:none' => 'Es gibt keine gemeldeten Beiträge.',
	'reportedcontent:report' => 'Einem Admin melden',
	'reportedcontent:deleted' => 'Die Meldung wurde gelöscht.',
	'reportedcontent:notdeleted' => 'Die Meldung konnte nicht gelöscht werden.',
	'reportedcontent:delete' => 'Meldung löschen',
	'reportedcontent:archive' => 'Meldung archivieren',
	'reportedcontent:archived' => 'Die Meldung wurde archiviert.',
	'reportedcontent:by' => 'Gemeldet von',
	'reportedcontent:objecttitle' => 'Titel des gemeldeten Beitrags',
	'reportedcontent:objecturl' => 'URL des gemeldeten Beitrags',
	'reportedcontent:reason' => 'Grund für die Meldung',
	'reportedcontent:description' => 'Warum möchtest Du diesen Beitrag melden?',
	'reportedcontent:address' => 'Adresse des Beitrags',
	'reportedcontent:success' => 'Deine Meldung wurde an den Admin gesendet.',
	'reportedcontent:refresh' => 'Auflistung neu laden',
	'reportedcontent:report' => 'Einem Admin melden',
	'reportedcontent:instructions' => 'Die Meldung wird an die Administratoren dieser Community-Seite gesendet, damit sie auf diesen Beitrag aufmerksam gemacht werden.',
	'reportedcontent:numbertodisplay' => 'Anzahl der anzuzeigenden Meldungen',
	'reportedcontent:user' => 'Benutzer melden',

	'reportedcontent:failed' => 'Entschuldigung, leider ist der Versuch, diesen Beitrag zu melden, gescheitert.',
	'reportedcontent:notarchived' => 'Die Meldung konnte nicht archiviert werden.',
	
	'widgets:reportedcontent:name' => 'Gemeldete Beiträge',
	'widgets:reportedcontent:description' => 'Gemeldete Beiträge anzeigen.',
);
